@@ -597,7 +597,7 @@ public:
      void setPreEPGmargin(int pre);
 
       /**
-     \fn int getPostEPGmargin()
+     \fn int getPostEPGmargin() const
      \author Marco Kraus <marco@klear.org>
      \retval int return post EPG margin
      \brief return the post margin value to set for EPG recording
